@@ -5,6 +5,7 @@ import time
 import requests
 import re
 import json
+import sys
 from auto_upload.utils.img_upload.imgupload import img_upload
 
 def deletetorrent(delpath=''):
@@ -18,6 +19,12 @@ def deletetorrent(delpath=''):
             logger.info('正在删除文件:'+c_path+'...')
             os.remove(c_path)
 
+def changename(pah):
+    if not 'win' in sys.platform:
+        return path
+    else:
+        return '/cygdrive/'+path.replace('\\','/').replace(':','')
+
 def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announce.php"):
 
     if os.path.isdir(filepath):
@@ -31,7 +38,7 @@ def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announ
         except Exception as r:
             logger.error('删除种子发生错误: %s' %(r))
     logger.info('正在制作种子:'+filepath)
-    order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+torrentname+ '\" \"'+filepath+'\"'+' > /dev/null'
+    order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+' > /dev/null'
     #logger.info(order)
     os.system(order)
     logger.info('已完成制作种子'+torrentname)
